<?php
/*
Plugin Name: PJW Wordpress Version Check
Plugin URI: http://ftwr.co.uk/blog/wordpress/version-check
Description: Monitors for wordpress version updates and displays info in the admin screen.
Author: Peter Westwood
Version: 0.75 beta
Author URI: http://ftwr.co.uk/blog/
*/ 

include_once(ABSPATH . WPINC . '/class-IXR.php');

/* Simple class to keep everything private */
class pjw_wp_version_check
{
	var $options = array("last_run"=>0,
						 "last_version"=>"",
						 "ixr_response"=>array("class" => "warning", 
					 						   "message" => "Failed to get update information."));

	function init()
	{
		add_option('pjw_wp_version_check',$this->options,'Settings for the version check plugin.','yes');
		$this->options = get_option('pjw_wp_version_check');
	}

	function update_if_required()
	{
		global $wp_version;

		if (($this->options["last_run"] + ( 15 * 60)) < time() || $this->options["last_version"] != $wp_version)
		{
			$ixrcli = new IXR_Client('http://sandbox.ftwr.co.uk/xmlrpc/wp.php');
			if ($ixrcli->query('wp.get_version_report',$wp_version))
			{
				$ixr_res = $ixrcli->getResponse();
				$this->options["ixr_response"] = $ixr_res;
				$this->options["last_run"] = time();
				$this->options["last_version"] = $wp_version;
				update_option('pjw_wp_version_check',$this->options);				
			}
			else
			{
				$ixr_res = array("class"=>"warning", 
								 "message" => "XML-RPC Error:".$ixrcli->getErrorCode().":".$ixrcli->getErrorMessage());
			}
		}
	}

	//The message
	function output_text() {
		echo "<p id='pjw_update' class='";
		echo $this->options["ixr_response"]["class"];
		echo "' >";
		echo $this->options["ixr_response"]["message"];
		echo "</p>";
	}

	// We need some CSS to position the paragraph
	function output_css() {
		echo "
			<style type='text/css'>
			#pjw_update {
				position: absolute;
				top: 5px;
				margin: 0; padding: 0;
				right: 1.5em;
				font-size: 20px;
			}
			.warning { color: orange; }
			.critical { color: red; text-decoration:blink; }
			.info { color: green; }
			</style>
			";
	}
}

/* Initialise outselves */
$pjw_wp_ver_chk = new pjw_wp_version_check;
$pjw_wp_ver_chk->init();
$pjw_wp_ver_chk->update_if_required();

/* add some actions */
add_action('admin_footer', array(&$pjw_wp_ver_chk,'output_text'));
add_action('admin_head', array(&$pjw_wp_ver_chk,'output_css'));
?>
